# -*- coding: utf-8 -*-

VERSION = (0, 2, 3)
PRERELEASE = None  # alpha, beta or rc
REVISION = None


def generate_version(version, prerelease=None, revision=None):
    version_parts = [".".join(map(str, version))]
    if prerelease is not None:
        version_parts.append(f"-{prerelease}")
    if revision is not None:
        version_parts.append(f".{revision}")
    return "".join(version_parts)


__title__ = "pdftopng"
__description__ = "A PDF to PNG conversion library."
__url__ = "https://github.com/vinayak-mehta/pdftopng"
__version__ = generate_version(VERSION, prerelease=PRERELEASE, revision=REVISION)
__author__ = "Vinayak Mehta"
__author_email__ = "vmehta94@gmail.com"
__license__ = "GPL-2.0"



# -*- coding: utf-8 -*-

import click

from . import pdftopng
from . import __version__


@click.command("pdftopng")
@click.version_option(version=__version__)
@click.argument("pdf_path", type=click.Path(exists=True))
@click.argument("png_path")
@click.pass_context
def cli(ctx, *args, **kwargs):
    """A PDF to PNG conversion tool (based on `pdftoppm` from `poppler`)"""

    pdf_path = kwargs["pdf_path"]
    png_path = kwargs["png_path"]

    pdftopng.convert(pdf_path=pdf_path, png_path=png_path)
